<?php
// $Id$

/**
 * @file
 * OM Maximenu Admin Configuration
 *
 * @author: Daniel Honrade http://drupal.org/user/351112
 *
 */
 
/**
 * Admin Form - Simple Editing
 *
 */
function om_maximenu_admin() {
  global $_om_maximenu_variable;
  
  // output options
  om_maximenu_admin_js();

  drupal_set_title(t('OM Maximenu Settings'));
  
  $maximenu = $_om_maximenu_variable;
  ksort($maximenu);
  
  //dsm($maximenu);
  $form = array();
  $form['om_maximenus'] = array(
    '#type' => 'fieldset',
    '#collapsible' => FALSE,
    '#collapsed' => FALSE,
    '#tree' => TRUE,
    '#description' => t('These OM Maximenu blocks are automatically added to <a href="@link">Block List</a> where you can place them in any region.', array('@link' => base_path() . 'admin/structure/block/list')),
  );
  
  // getting existing roles
  $result = db_query("SELECT rid, name, weight FROM {role} ORDER BY rid ASC");
  
  $roles = array();  
  while ($record = $result->fetchObject()) {
    $roles[$record->rid] = $record->name;
  }
  
  // Existing menus and links
  $maximenu_array = array();
  if (!empty($maximenu)) {
    foreach ($maximenu as $menu_key => $menu_content) {
      $maximenu_array[$menu_key] = array(
        '#type'        => 'fieldset',
        '#title'       => om_string_name($menu_content['title'], FALSE),
        '#collapsible' => TRUE,
        '#collapsed'   => TRUE,
        '#attributes' => array('id' => 'om-maximenu-fieldset-' . om_string_name($menu_content['title']), 'class' => array('om-maximenu-fieldset')),                
      );  
      //dsm($menu_content);
      $menu_content['menu_key']   = $menu_key;
      $menu_content['roles']      = $roles;    
      $maximenu_array[$menu_key] += _om_maximenu_admin($menu_content);
    }
  }
  
  // New menu and links
  // new ids relies on highest menu key id
  // adding only 1 new blank menu
  $count = !empty($maximenu) ? max(array_keys($maximenu)) + 1: 1;

  $menu_content_new = array(
    'title'    => 'New Menu',
    'skin'     => 'bubble',        
    'fade'     => 0,   
    'output'   => 'block',        
    'links'    => array(),
    'menu_key' => $count,
    'roles'    => $roles,
  );   

  $maximenu_array[$count] = array(
    '#type'        => 'fieldset',
    '#title'       => 'New Menu',
    '#collapsible' => TRUE,
    '#collapsed'   => TRUE,
    '#attributes' => array('id' => 'om-maximenu-fieldset-new-menu', 'class' => array('om-maximenu-fieldset')),                
  );  
  
  $maximenu_array[$count] += _om_maximenu_admin($menu_content_new);
  
  $form['om_maximenus'] += $maximenu_array; 
  
  $form['save'] = array( '#type' => 'submit', '#value' => t('Save'), );
  
  return $form;
}


/**
 * Admin Form
 *
 */
function _om_maximenu_admin($menu_content = array()) {

  static $first_menu = 0;
  $skin     = om_maximenu_style_get();
  $roles    = $menu_content['roles'];
  $menu_key = $menu_content['menu_key'];
  
  $out = array();
  // delete field is for saved menus only
  if (trim($menu_content['title']) != 'New Menu') {
    $out['delete'] = array(
      '#type'  => 'checkbox',
      '#title' => t('Delete this menu.'),    
      '#default_value' => 0,
    );
  }
  $out['title'] = array(
    '#type'  => 'textfield',
    '#title' => t('Menu Block Title'),  
    '#required' => TRUE,  
    '#default_value' => isset($menu_content['title']) ? trim($menu_content['title']): 'New Menu',
  );
  $out['skin'] = array(
    '#type'  => 'select',
    '#title' => t('Skin'),
    '#options' => $skin,    
    '#default_value' => isset($menu_content['skin']) ? $menu_content['skin']: 'bubble',
  ); 
  $out['fade'] = array(
    '#type'  => 'checkbox',
    '#title' => t('Fade Effect'),
    '#default_value' => isset($menu_content['fade']) ? $menu_content['fade']: 0,
  ); 
  
  // the script only allows 1 menu
  $animated_bg_switch = (($first_menu == 0) || (isset($menu_content['animated_bg']) && ($menu_content['animated_bg'] == 1))) ? 1: 0; 
  if ($animated_bg_switch == 1) {    
    $out['animated_bg'] = array(
      '#type'  => 'checkbox',
      '#title' => t('Animated Background'),
      '#default_value' => isset($menu_content['animated_bg']) ? $menu_content['animated_bg']: 0,
    ); 
  }
  $output_options = array('block' => 'Block', 'float' => 'Floating'); 
  // Only 1 main menu is allowed
  // the first menu is always the priority to be with main menu option
  $main_menu_switch = (($first_menu == 0) || (isset($menu_content['main_menu']) && ($menu_content['main_menu'] == 1))) ? 1: 0;
  if ($main_menu_switch == 1) { 
    $output_options = array('block' => 'Block', 'float' => 'Floating', 'main_menu' => 'Main Menu');
    $main_menu_option_desc = t('<li><strong>Main Menu</strong> - You have the option to make this as your main menu. <br />
      This will automatically replace existing main menu for OM Base Theme. <br />
      For other themes, add this &lt;?php print $main_menu_tree; ?&gt; to your page.tpl.php</li>');   
  }
  else {
    $main_menu_option_desc = '';
  }
  
  $first_menu++; // ensures above is executed once of value is 0

  $out['output'] = array(
    '#type'  => 'select',
    '#title' => t('Output Options'),
    '#options' => $output_options,    
    '#default_value' => isset($menu_content['output']) ? $menu_content['output']: 'block',
    '#attributes' => array('class' => array('om-maximenu-output')),        
    '#description' => t('
      <ul>
        <li><strong>Block</strong> - will appear in the block list.</li>
        <li><strong>Floating</strong> - goes left, middle, right of the screen.</li>
        '  . $main_menu_option_desc . '
      </ul>
     '),    
  );  

  $out['block_options'] = array(
    '#type'  => 'fieldset',
    '#title' => t('Block Options'),
    '#collapsible' => TRUE,
    '#collapsed'   => FALSE, 
    '#attributes' => array(
      'class' => array('om-maximenu-block-options'), 
      'style' => ($menu_content['output'] == 'block') ? 'display: block;': 'display: none;',
    ),    
  );  

  $out['block_options']['direction'] = array(
    '#type'  => 'select',
    '#title' => t('Block Menu Direction'),
    '#options' => array('block-down' => 'Dropdown','block-up' => 'Dropup', 'block-right' => 'Right', 'block-left' => 'Left'),    
    '#default_value' => isset($menu_content['block_options']['direction']) ? $menu_content['block_options']['direction']: 'block-down', 
    '#attributes' => array('id' => 'block-options-direction-' . $menu_key), 
    '#description' => t('OM Maximenu will popup on this direction'),                   
  );     

  $out['float_options'] = array(
    '#type'  => 'fieldset',
    '#title' => t('Float Options'),
    '#collapsible' => TRUE,
    '#collapsed'   => FALSE, 
    '#attributes' => array(
      'class' => array('om-maximenu-float-options'), 
      'style' => ($menu_content['output'] == 'float') ? 'display: block;': 'display: none;',
    ),    
  ); 
  
  $out['float_options']['position'] = array(
    '#type'  => 'select',
    '#title' => t('Fixed / Absolute'),
    '#options' => array('fixed' => 'Fixed', 'absolute' => 'Absolute'),    
    '#default_value' => isset($menu_content['float_options']['position']) ? $menu_content['float_options']['position']: 'fixed',
    '#description' => t('
      <ul>
        <li><strong>Fixed</strong> - stays on screen on scrolling</li>
        <li><strong>Absolute</strong> - moves with the page on scrolling</li>
      </ul>
     '),         
  );     
  $out['float_options']['y_origin'] = array(
    '#type'  => 'select',
    '#title' => t('Y-Origin: Top / Bottom'),
    '#options' => array('top' => 'Top', 'bottom' => 'Bottom'),    
    '#default_value' => isset($menu_content['float_options']['y_origin']) ? $menu_content['float_options']['y_origin']: 'bottom',        
  ); 
  $out['float_options']['y_value'] = array(
    '#type'  => 'textfield',
    '#title' => t('Y-Axis Value'),
    '#size'  => 5,
    '#default_value' => isset($menu_content['float_options']['y_value']) ? $menu_content['float_options']['y_value']: 10,        
  );
  $out['float_options']['x_origin'] = array(
    '#type'  => 'select',
    '#title' => t('X-Origin: Left / Middle / Right'),
    '#options' => array('left' => 'Left', 'middle' => 'Middle', 'right' => 'Right'),    
    '#attributes' => array('class' => array('om-maximenu-x-origin')),
    '#default_value' => isset($menu_content['float_options']['x_origin']) ? $menu_content['float_options']['x_origin']: 'left',        
  ); 
  $out['float_options']['non_middle_options'] = array(
    '#type'  => 'fieldset',
    '#title' => t('Non-Middle Options'),
    '#collapsible' => TRUE,
    '#collapsed'   => FALSE, 
    '#attributes' => array(
      'class' => array('om-maximenu-non-middle-options'), 
      'style' => (isset($menu_content['float_options']['x_origin']) && ($menu_content['float_options']['x_origin'] == 'middle')) ? 'display: none;': 'display: block;',
    ),    
  );  

  $out['float_options']['non_middle_options']['x_value'] = array(
    '#type'  => 'textfield',
    '#title' => t('X-Axis Value'),
    '#size'  => 5,    
    '#default_value' => isset($menu_content['float_options']['x_value']) ? $menu_content['float_options']['x_value']: 10,        
    '#attributes' => array('class' => array('om-maximenu-x-value')),
  );

  $out['float_options']['non_middle_options']['stacking'] = array(
    '#type'  => 'select',
    '#title' => t('Stacking'),
    '#options' => array('row' => 'Row', 'column' => 'Column'),    
    '#default_value' => isset($menu_content['float_options']['stacking']) ? $menu_content['float_options']['stacking']: 'row',        
    '#attributes' => array('class' => array('om-maximenu-stacking')),
    '#description' => t('
      <ul>
        <li><strong>Row</strong> - all links in 1 row</li>
        <li><strong>Column</strong> -all links in 1 column</li>
      </ul>
     '), 
  ); 
  $out['float_options']['non_middle_options']['orientation'] = array(
    '#type'  => 'select',
    '#title' => t('Orientation'),
    '#options' => array('horizontal' => 'Horizontal', 'vertical' => 'Vertical'),    
    '#default_value' => isset($menu_content['float_options']['orientation']) ? $menu_content['float_options']['orientation']: 'horizontal',        
    '#attributes' => array('class' => array('om-maximenu-orientation')),
    '#description' => t('
      <ul>
        <li><strong>Horizontal</strong> - normal text/icon orientation</li>
        <li><strong>Vertical</strong> - left(90deg rotation), right(270deg rotation)</li>
      </ul>
     '), 
  ); 

  $out['float_options']['dock'] = array(
    '#type'  => 'checkbox',
    '#title' => t('Dock Effect'),
    '#default_value' => isset($menu_content['float_options']['dock']) ? $menu_content['float_options']['dock']: 0,
    '#attributes' => array('id' => 'float-options-position-' . $menu_key),                     
    '#description' => t('Mac-like zoom effect on menu icons.'),
  ); 
     
  if (!isset($menu_content['links'])) $menu_content['links'] = array();
  
  // This makes sure that even if existing links are deleted
  // it won't have an id below the existing ones
  // new link ids will depend on the highest existing link id;
  $count = !empty($menu_content['links']) ? max(array_keys($menu_content['links'])) + 1: 1;
  
  $menu_content['links'] += _om_new_link($count, $roles);
 
  $links = array();
  foreach ($menu_content['links'] as $link => $prop) {
    // count enabled blocks 
    $enabled_blocks = (isset($prop['content']) && !empty($prop['content'])) ? count($prop['content']): 0;  

    $link_title  = (isset($prop['link_title']) && !empty($prop['link_title'])) ? trim($prop['link_title']): 'New Link';
   // php on title
    if (isset($prop['php_option']) && ($prop['php_option'] == 1)) {
      ob_start();
      $link_title = eval($prop['link_title']);
      //$output = ob_get_contents();
      ob_end_clean(); 
    } 
    
    $links[$link] = array(
      '#type'   => 'fieldset',
      '#title'  => strip_tags($link_title),
      '#collapsible' => TRUE,
      '#collapsed'   => TRUE,
      '#description' => (!empty($link_title) && ($link_title != 'New Link')) ? t('@enabled_blocks enabled blocks, <strong><a href="@link">Click here </a></strong> to Enable/Disable blocks on this link.', array('@enabled_blocks' => $enabled_blocks, '@link' => base_path() . 'admin/structure/om-maximenu/blocks/' . $menu_key . '/' . $link . '?destination=admin/structure/om-maximenu')): t('<strong>You can only enable/disable blocks on this link if you have modified the link title.</strong>'),         
    );
    
    // delete field is only for existing links
    if ($link_title != 'New Link') {
      $links[$link]['link_delete'] = array(
        '#type'   => 'checkbox',
        '#title'  => 'Delete this link.',
        '#default_value'  => 0,      
      );    
    }
    $links[$link]['link_title'] = array(
      '#type'   => 'textarea',
      '#title'  => 'Link Title',
      '#rows' => 1,
      '#required' => TRUE,        
      '#default_value'  => (isset($prop['link_title']) && !empty($prop['link_title'])) ? trim(stripslashes($prop['link_title'])): 'New Link',      
      '#description' => t('You can add inline styling or other attributes, ex. &lt;span class="special-link" style="font-weight: bold;"&gt;Home&lt;/span&gt;'),      
    ); 
    $links[$link]['title_options'] = array(
      '#type'   => 'fieldset',
      '#title'  => t('Title Options'),
      '#collapsible' => TRUE,
      '#collapsed'   => TRUE,
    );      
    $links[$link]['title_options']['link_title_option'] = array(
      '#type'   => 'select',
      '#title'  => 'Options for Link Title',
      '#default_value'  => isset($prop['link_title_option']) ? $prop['link_title_option']: 'title',
      '#options' => array('title' => 'Title only', 'title_icon' => 'Title with Icon', 'icon' => 'Icon only'),
    );        
    $links[$link]['title_options']['path_icon'] = array(
      '#type'   => 'textfield',
      '#title'  => 'Icon Path',
      '#default_value'  => isset($prop['path_icon']) ? trim($prop['path_icon']): '',
      '#description' => t('
        Ex. sites/default/themes/mytheme/css/images/icon_1.png or<br />
        sites/default/files/icon_1.png <br />        
        (By default, this icon will go to the left side of the link title.). <br />
        This can also be done via css properties, ex .link-home { background: url(...)...'),      
    );  
    $links[$link]['title_options']['icon_option'] = array(
      '#type'   => 'checkbox',
      '#title'  => 'Icon Hover Image',
      '#default_value'  => isset($prop['icon_option']) ? $prop['icon_option']: 0,
      '#description' => t('You can have a mouseover icon, just upload another image, Ex. icon.png, icon_hover.png, <br />
        just add "_hover" to the second image and this will automatically replace your active state icon on mouseover.'),      
    ); 
    $links[$link]['title_options']['php_option'] = array(
      '#type'   => 'checkbox',
      '#title'  => 'Title has PHP',
      '#default_value'  => isset($prop['php_option']) ? $prop['php_option']: 0,
      '#description' => t('DO NOT include &lt;?php and ?&gt;, always add a return value, <br />
         ex. <strong> global $user; return \'&lt;strong&gt;\' . $user->name . \'&lt;/strong&gt;\';</strong>",<br />
         make sure your code is valid php, any error on this can potentially break your site.'),      
    );    
    $links[$link]['path'] = array(
      '#type'   => 'textfield',
      '#title'  => 'Path',
      '#default_value'  => isset($prop['path']) ? trim($prop['path']): '',
      '#description' => t('
        <ul>
          <li><strong>Front Page</strong> - put &lt;front&gt; as path.</li>
          <li><strong>No Link</strong> - empty path is valid and will transform "a" tag to "span" tag.</li>
          <li><strong>Anchor</strong> - accepts "#" as valid path, which can correspond to id properties of a tag, ex. &lt;div id="section-1",<br /> 
          so you can now target this section by doing "about#section-1", and the page will automatically scroll to that section.</li>
        </ul>  
          '),      
    );
    $links[$link]['weight'] = array(
      '#type'   => 'weight',
      '#title'  => 'Weight',
      '#delta' => 20,        
      '#default_value'  => isset($prop['weight']) ? $prop['weight']: 0,
      '#description' => t('Negative values have the highest order, so -1 comes first before 0 then 1, ...'),      
    );    
    $links[$link]['attributes'] = array(
      '#type'   => 'fieldset',
      '#title'  => t('Link Attributes'),
      '#collapsible' => TRUE,
      '#collapsed'   => TRUE,
    );                    
    $links[$link]['attributes']['id'] = array(
      '#type'   => 'textfield',
      '#title'  => 'ID',
      '#default_value'  => isset($prop['id']) ? trim($prop['id']): '',
      '#description' => t('Make sure this ID is unique.'),      
    );
    $links[$link]['attributes']['class'] = array(
      '#type'   => 'textfield',
      '#title'  => 'Classes',
      '#default_value'  => isset($prop['class']) ? trim($prop['class']): '',
      '#description' => t('It\'s a good practice to have classes in lowercase and dashes separating words.'),
    );
    $links[$link]['attributes']['rel'] = array(
      '#type'   => 'textfield',
      '#title'  => 'Relationship',
      '#default_value'  => isset($prop['rel']) ? trim($prop['rel']): '',
      '#description' => t('
        <ul>
          <li><strong>nofollow</strong> - for search engines not to follow the link.</li>
          <li><strong>lightbox</strong> - if you installed Lighbox 2, see your other options on Lightbox 2 README.txt.</li>
          <li>Other modules may have uses for this, so I just kept it as textfield.</li>
        </ul> 
      '),            
    );  
    $links[$link]['attributes']['target'] = array(
      '#type'   => 'select',
      '#title'  => 'Target Window',
      '#options' => array(
        '_self'   => 'Self', 
        '_blank'  => 'Blank',
        '_parent' => 'Parent',         
        '_top'    => 'Top',                                          
      ),
      '#default_value'  => isset($prop['target']) ? $prop['target']: '_self',
    );       
    $links[$link]['attributes']['description'] = array(
      '#type'   => 'textfield',
      '#title'  => 'Description',
      '#default_value'  => isset($prop['description']) ? $prop['description']: '',
      '#description' => t('Link additional information'),            
    );
    $links[$link]['attributes']['description_option'] = array(
      '#type'   => 'select',
      '#title'  => 'Options for description',
      '#options' => array('hover' => 'Hover', 'subtitle' => 'Subtitle'),
      '#default_value'  => isset($prop['description_option']) ? $prop['description_option']: 'hover',
      '#description' => t('
        <ul>
          <li><strong>Hover</strong> - appears on mouse over the link.</li>
          <li><strong>Subtitle</strong> - appears as text under the link.</a>.</li>
        </ul> 
      '),
    );  
    $links[$link]['permission'] = array(
      '#type'   => 'fieldset',
      '#title'  => t('Permission'),
      '#collapsible' => TRUE,
      '#collapsed'   => TRUE,
    );         
    $links[$link]['permission']['roles'] = array(
      '#type'    => 'checkboxes',
      '#title'   => 'User Roles',
      '#options' => $roles,
      '#default_value'  => isset($prop['roles']) ? $prop['roles']: array(),
      '#description' => t('If none is checked, this link will appear for all users.'),      
    );    
    //dsm($prop['content']);
    // these are the blocks
    if (isset($prop['content']) && is_array($prop['content'])) {
      foreach ($prop['content'] as $block => $block_prop) {
        foreach ($block_prop as $block_key => $block_val) {    
          $links[$link]['content'][$block][$block_key] = array(
            '#type'   => 'hidden',
            '#default_value'  => isset($block_val) ? trim($block_val): '',
          );
        }
      }
    }
  }
  
  $out['links'] = array(
    '#type'  => 'fieldset',
    '#title' => t('Menu Links'),
    '#collapsible' => TRUE,
    '#collapsed'   => TRUE,   
  );   
  
  $out['links'] += $links;

  return $out;
}


/**
 * OM Default New Links
 *
 */
function _om_new_link($count = 0, $roles = array()) {

  $num = $count + 5; // additional 5 new blank links
  
  $out = array();
  for ($i = $count; $i < $num; $i++) {
    // new links with default values
    $out[$i] = array(
      'link_title'         => 'New Link',
      'link_title_option'  => 'title',  
      'path_icon'          => '',                
      'icon_option'        => 0,
      'php_option'         => 0, 
      'path'               => '',      
      'weight'             => 0,  
      'id'                 => '',
      'class'              => '',
      'rel'                => '',
      'target'             => '_self',            
      'description'        => '',
      'description_option' => 'hover',      
      'roles'              => $roles,      
    );
  }
  return $out;
}


/**
 * 1 Submit for all settings
 *
 */
function om_maximenu_admin_submit($form, $form_state) {

  $om_maximenu_array = $form_state['values']['om_maximenus'];
  //dsm($om_maximenu_array); 
  
  $om_maximenu = array();
  foreach ($om_maximenu_array as $menu_id => $maximenu_block_content) {
    
    if (!isset($maximenu_block_content['delete'])) $maximenu_block_content['delete'] = 0; 
    // menu will not be included in the array if the title is not modified and delete field is checked
    if (!empty($maximenu_block_content['title']) && ($maximenu_block_content['title'] != 'New Menu') && ($maximenu_block_content['delete'] != 1)) {
      
      $om_maximenu[$menu_id] = array(
        'title'       => $maximenu_block_content['title'],
        'skin'        => $maximenu_block_content['skin'],
        'fade'        => $maximenu_block_content['fade'],
        'output'      => $maximenu_block_content['output'],        
      ); 
      
      if (isset($maximenu_block_content['animated_bg']) && ($maximenu_block_content['animated_bg'] == 1)) $om_maximenu[$menu_id]['animated_bg'] = 1;  
            
      if ($maximenu_block_content['output'] == 'block') {
        $om_maximenu[$menu_id]['block_options']['direction'] = $maximenu_block_content['block_options']['direction'];
      }
      elseif ($maximenu_block_content['output'] == 'float') {
        $om_maximenu[$menu_id]['float_options']['position']    = $maximenu_block_content['float_options']['position'];
        $om_maximenu[$menu_id]['float_options']['y_origin']    = $maximenu_block_content['float_options']['y_origin'];        
        $om_maximenu[$menu_id]['float_options']['y_value']     = $maximenu_block_content['float_options']['y_value'];        
        $om_maximenu[$menu_id]['float_options']['x_origin']    = $maximenu_block_content['float_options']['x_origin'];
        if ($maximenu_block_content['float_options']['x_origin'] != 'middle') {
          $om_maximenu[$menu_id]['float_options']['x_value']     = $maximenu_block_content['float_options']['non_middle_options']['x_value'];               
          $om_maximenu[$menu_id]['float_options']['stacking']    = $maximenu_block_content['float_options']['non_middle_options']['stacking'];  
          $om_maximenu[$menu_id]['float_options']['orientation'] = $maximenu_block_content['float_options']['non_middle_options']['orientation'];
        }                
        if (isset($maximenu_block_content['float_options']['dock']) && ($maximenu_block_content['float_options']['dock'] == 1)) $om_maximenu[$menu_id]['float_options']['dock'] = 1;          
      }
      
      foreach ($maximenu_block_content['links'] as $link => $link_prop) {
        
        if (!isset($link_prop['link_delete'])) $link_prop['link_delete'] = 0; 
        // links will not be included in the array if the title is not modified and delete field is checked
        if (!empty($link_prop['link_title']) && ($link_prop['link_title'] != 'New Link') && ($link_prop['link_delete'] != 1)) {
          $om_maximenu[$menu_id]['links'][$link] = array(
            'link_title'         => $link_prop['link_title'],
            'link_title_option'  => $link_prop['title_options']['link_title_option'],
            'path_icon'          => $link_prop['title_options']['path_icon'],
            'icon_option'        => $link_prop['title_options']['icon_option'],  
            'php_option'         => $link_prop['title_options']['php_option'],
            'path'               => $link_prop['path'], 
            'weight'             => $link_prop['weight'],                                
            'id'                 => $link_prop['attributes']['id'],
            'class'              => $link_prop['attributes']['class'],
            'rel'                => $link_prop['attributes']['rel'],
            'target'             => $link_prop['attributes']['target'],                        
            'description'        => $link_prop['attributes']['description'],
            'description_option' => $link_prop['attributes']['description_option'],            
            'roles'              => $link_prop['permission']['roles'],            
            'content'            => isset($link_prop['content']) ? $link_prop['content']: '',

          );
        }
      }
    }
  }

  drupal_set_message(t('Your settings have been saved.'));
  
  // Save all settings in 1 variable
  variable_set('om_maximenu', $om_maximenu);
} 


/**
 * Adding Blocks
 * 
 * List of all available blocks in the system
 *
 */
function om_maximenu_blocks_get() {
  global $_om_maximenu_variable;
    
  drupal_set_title(t('OM Maximenu Blocks'));
  
  // get the variable to merge with enabled blocks
  $maximenu = $_om_maximenu_variable;
  
  // based on url variables
  $args            = arg();  
  $menu_title      = isset($maximenu[$args[4]]['title']) ? $maximenu[$args[4]]['title']: '';
  $link_title      = isset($maximenu[$args[4]]['links'][$args[5]]['link_title']) ? $maximenu[$args[4]]['links'][$args[5]]['link_title']: 'New Link';
  $link_title_path = isset($maximenu[$args[4]]['links'][$args[5]]['link_title_path']) ? $maximenu[$args[4]]['links'][$args[5]]['link_title_path']: '';  
  $blocks_enabled  = isset($maximenu[$args[4]]['links'][$args[5]]['content']) ? $maximenu[$args[4]]['links'][$args[5]]['content']: array();
  //dsm($blocks_enabled);

  $theme_default = variable_get('theme_default', 'garland');

  // default, module generated blocks
  $result = db_query("SELECT module, delta, title FROM {block} WHERE theme = :theme_default ORDER BY module, delta ASC", array(':theme_default' => $theme_default));
  
  while ($record = $result->fetchObject()) {
  
    // filter out om_maximenu module
    if ($record->module != 'om_maximenu') {
      // to get the default block title
      $block  = block_load($record->module, $record->delta); 
      $title  = $record->title; 
      $module = $record->module;
      $delta  = $record->delta;    
      // checked state is based on blocks existence in the array
      $modules[$module][$delta]['checked'] = isset($blocks_enabled[$module . '___' . $delta]) ? 1: 0; 
      //print $blocks_enabled[$module][$delta];  
      
      if (isset($blocks_enabled[$module . '___' . $delta]) && !empty($blocks_enabled[$module . '___' . $delta]['title'])) {  
        // if custom title is present     
        $modules[$module][$delta]['title'] =  $blocks_enabled[$module . '___' . $delta]['title'];       
      }
      else {
        $modules[$module][$delta]['title'] =  empty($block->subject) ? om_string_name($module, FALSE) . ' ' . $delta: $block->subject; 
      }
      $modules[$module][$delta]['title_path'] =  isset($blocks_enabled[$module . '___' . $delta]) ? $blocks_enabled[$module . '___' . $delta]['title_path']: '';             
    }
  }
  //dsm($modules);
  $form = array();  
  $form['om_maximenu_content'] = array(
    '#type'        => 'fieldset',
    '#title'       => t($menu_title . ' / ' . $link_title),
    '#collapsible' => TRUE,
    '#collapsed'   => FALSE,
    '#tree'        => TRUE,
    '#description' => t('These are all the available blocks in your system. Choose the blocks which will appear under the navigation menu link.'),
  );
  
  foreach ($modules as $module => $blocks) {
  
    // count all blocks in a module
    $total = count($modules[$module]);
    
    // count how many are enabled
    $count = 0;
    foreach ($blocks as $key => $checked) {
      if ($checked['checked']) $count++;
    } 
    
    $form['om_maximenu_content'][$module] = array(
      '#type'        => 'fieldset',
      '#title'       => t(om_string_name($module, FALSE) . ' (' . $count . ' of ' . $total . ')'),
      '#collapsible' => TRUE,
      '#collapsed'   => TRUE,
    );
    foreach ($blocks as $delta => $value) {
      $form['om_maximenu_content'][$module][$module . '___' . $delta] = array(
        '#type'          => 'fieldset',
        '#title'         => (trim($value['title'] != '<none>')) ? om_string_name($value['title'], FALSE): ucwords(t($module . ' ' . $delta)),
        '#collapsible' => TRUE,
        '#collapsed'   => FALSE,
      );     
      $form['om_maximenu_content'][$module][$module . '___' . $delta]['checked'] = array(
        '#type'          => 'checkbox',
        '#title'         => t('Enabled'), 
        '#default_value' => isset($value['checked']) ? $value['checked']: 0,   
      );     
      $form['om_maximenu_content'][$module][$module . '___' . $delta]['title'] = array(
        '#type'          => 'textfield',
        '#title'         => t('Title'), 
        '#default_value' => isset($value['title']) ? trim(stripslashes($value['title'])): '',  
        '#description' => t('Put &lt;none&gt; for no title. You can add inline styling or other attributes, <br />
          ex. &lt;span class="special-link" style="font-weight: normal;"&gt;My Title&lt;/span&gt;'), 
      );
      $form['om_maximenu_content'][$module][$module . '___' . $delta]['title_path'] = array(
        '#type'          => 'textfield',
        '#title'         => t('Path'), 
        '#default_value' => isset($value['title_path']) ? trim($value['title_path']): '',  
        '#description' => t('You can make the title clickable by adding a path. Ex. &lt;front&gt;, somepath, node/1'), 
      );      
      $form['om_maximenu_content'][$module][$module . '___' . $delta]['module'] = array(
        '#type'          => 'hidden',
        '#default_value' => $module,   
      );        
      $form['om_maximenu_content'][$module][$module . '___' . $delta]['delta'] = array(
        '#type'          => 'hidden',
        '#default_value' => $delta,   
      ); 
      $form['om_maximenu_content'][$module][$module . '___' . $delta]['weight'] = array(
        '#type'          => 'weight',
        '#title'         => t('Weight'),
        '#delta'         => 20,
        '#default_value' => isset($value['weight']) ? $value['weight']: 0,   
        '#description' => t('Negative values have the highest order, so -1 comes first before 0 then 1, ...'),              
      ); 
    }
  }   
   
  $form['save'] = array( '#type' => 'submit', '#value' => t('Save'), );
    
  return $form;
}  


/**
 * Adding Blocks Submit
 *
 */
function om_maximenu_blocks_get_submit($form, $form_state) {
  global $_om_maximenu_variable;
  
  $args = arg();
  $maximenu_content = $form_state['values']['om_maximenu_content'];
  //dsm($maximenu_content);
  $content = array();
  foreach ($maximenu_content as $module => $blocks) {
    foreach ($blocks as $block => $value) {
      if ($value['checked']) {
        $content[$block] = array(
          'title'      => $value['title'],
          'title_path' => $value['title_path'],          
          'module'     => $value['module'], 
          'delta'      => $value['delta'],  
          'weight'     => $value['weight'],            
        );                     
      }
    }
  }
  // get the om maximenu variable
  $om_maximenu = $_om_maximenu_variable;
  
  // added to om maximenu array the content
  $om_maximenu[$args[4]]['links'][$args[5]]['content'] = $content;
  //dsm($om_maximenu);
  drupal_set_message(t('Your settings have been saved.'));
  
  // Save all settings in 1 variable
  variable_set('om_maximenu', $om_maximenu);
} 




